==> incognito-js-0.1.6.tgz: package/index.ts <==
import '@src/utils/polyfill.ts';
import '@src/global';
import { checkCachedHistories, getTxHistoryByPublicKey } from '@src/services/history/txHistory';
import { implementGoMethodManually, implementGoMethodUseWasm, GO_METHOD_NAMES } from '@src/go';
import { setPrivacyUtilRandomBytesFunc } from '@src/services/wallet';
import { removeBridgeHistory } from '@src/services/bridge/history';
import * as _CONSTANT from '@src/constants/constants';
import * as _TX_CONSTANT from '@src/constants/tx';
import * as _WALLET_CONSTANT from '@src/constants/wallet';
import _TOKEN_INFO_CONSTANT from '@src/constants/tokenInfo';

export { default as AccountInstance } from '@src/walletInstance/account/account';
export { default as NativeTokenInstance } from '@src/walletInstance/token/nativeToken';
export { default as PrivacyTokenInstance } from '@src/walletInstance/token/privacyToken';
export { default as WalletInstance } from '@src/walletInstance/wallet';
export { default as MasterAccount } from '@src/walletInstance/account/masterAccount';
export { default as KeyWalletModel } from '@src/models/key/keyWallet';
export { default as AccountKeySetModel } from '@src/models/key/accountKeySet';
export { default as PaymentInfoModel } from '@src/models/paymentInfo';
export { default as storageService } from '@src/services/storage';
export { default as TxHistoryModel } from '@src/models/txHistory';
export { setConfig, getConfig } from '@src/config';
export { default as BN } from 'bn.js';
export { getPrivacyTokenList } from '@src/services/bridge/token';

export const historyServices = {
  checkCachedHistories,
  getTxHistoryByPublicKey
};

export const walletServices = {
  setPrivacyUtilRandomBytesFunc
};

export const goServices = {
  implementGoMethodManually,
  implementGoMethodUseWasm,
  GO_METHOD_NAMES
};

export const bridgeServices = {
  removeBridgeHistory
};

export const CONSTANT = {
  ..._CONSTANT,
  TX_CONSTANT: _TX_CONSTANT,
  WALLET_CONSTANT: _WALLET_CONSTANT,
  TOKEN_INFO_CONSTANT: _TOKEN_INFO_CONSTANT
};

==> incognito-js-1.4.0.tgz: package/index.ts <==
import '@src/utils/polyfill.ts';
import '@src/global';

import {
  implementGoMethodManually,
  implementGoMethodUseWasm,
  GO_METHOD_NAMES,
} from '@src/go';
import { setPrivacyUtilRandomBytesFunc } from '@src/services/wallet';
import * as _CONSTANT from '@src/constants/constants';
import * as _TX_CONSTANT from '@src/constants/tx';
import * as _WALLET_CONSTANT from '@src/constants/wallet';
import * as HISTORY_CONSTANT from '@src/constants/history';
import _TOKEN_INFO_CONSTANT from '@src/constants/tokenInfo';
import { checkPaymentAddress } from '@src/services/key';
export { default as AccountInstance } from '@src/walletInstance/account/account';
export { default as NativeTokenInstance } from '@src/walletInstance/token/nativeToken';
export { default as PrivacyTokenInstance } from '@src/walletInstance/token/privacyToken';
export { default as WalletInstance } from '@src/walletInstance/wallet';
export { default as MasterAccount } from '@src/walletInstance/account/masterAccount';
export { default as KeyWalletModel } from '@src/models/key/keyWallet';
export { default as AccountKeySetModel } from '@src/models/key/accountKeySet';
export { default as PaymentInfoModel } from '@src/models/paymentInfo';
export { default as storageService } from '@src/services/storage';
export { default as mnemonicService } from '@src/services/wallet/mnemonic';
export { default as TxHistoryModel } from '@src/models/txHistory';
export * from '@src/models/txHistory';
export { setConfig, getConfig, getToken } from '@src/config';
export { getPrivacyTokenList } from '@src/services/bridge/token';
export { default as rpcClient } from '@src/services/rpc';
export { default as SDKError } from '@src/constants/error';

export * from '@src/services/history/txHistory';
export * from '@src/services/bridge/deposit';
export * from '@src/services/bridge/withdraw';
export * from '@src/services/bridge/token';
export * from '@src/services/bridge/history';
export * from '@src/services/user/profile';

export const walletServices = {
  setPrivacyUtilRandomBytesFunc,
};

export const goServices = {
  implementGoMethodManually,
  implementGoMethodUseWasm,
  GO_METHOD_NAMES,
};

export const keyServices = {
  checkPaymentAddress,
};

export const CONSTANT = {
  ..._CONSTANT,
  TX_CONSTANT: _TX_CONSTANT,
  WALLET_CONSTANT: _WALLET_CONSTANT,
  TOKEN_INFO_CONSTANT: _TOKEN_INFO_CONSTANT,
  HISTORY: HISTORY_CONSTANT.HISTORY,
};
